body {
  font-family: "Source Sans Pro", sans-serif;
  -webkit-font-smoothing: antialiased;
  text-rendering: optimizeLegibility;
  font-weight: 400;
}
.masthead {
  background: #3580ca url("/static/img/top-bg.gif") repeat-x center bottom;
  min-height: 100px;
  padding-top: 10px;
}
